@@ -113,10 +113,12 @@ sub run_tests {
   if(!$pkg->isa('Test::FITesque::Suite')){
     my $Builder = $TEST_BUILDER ? $TEST_BUILDER : Test::Builder->new();
     $Builder->exported_to(__PACKAGE__);
-    if( my $count = $self->test_count() ){
-      $Builder->expected_tests($count);
-    } else {
-      $Builder->no_plan();
+    if ( $Builder->isa('Test::FakeBuilder') || !$Builder->has_plan) {
+        if( my $count = $self->test_count() ){
+          $Builder->expected_tests($count);
+        } else {
+          $Builder->no_plan();
+        }
     }
   }
   
