@@ -7,6 +7,6 @@ sub new { return bless {}, $_[0]; }
 sub exported_to {}
 sub no_plan {}
 sub expected_tests {}
-sub note {}
+sub diag {}
 
 1;
